HEAVY FLOW
==========
An asynchronous flow-control library for node and CommonJS. Sure, there are a bunch of these, but this one's different.

WHY IS IT DIFFERENT SIR??
========================
It's simpler, smaller, and more readable by virtue of being only vaguely Promise-based. It solves the callback nightmare of this:

```javascript
asyncFn1(err, data) {
	asyncFn2(err, data) {
		asyncFn3(err, data) {
			// ...
		}
	}
}
```

...but doesn't need bunches of when/then/parallel/etc. functions to do independent asynchrony or manage dependencies. All it uses is a ```wait()``` function and a ```ready()``` callback, although it throws in some nice ```finished()``` and ```cancelled()``` callbacks to make success, exception, and error handling easier.

WATCH THIS
==========
```javascript
var flow = require('./heavy-flow');

// this is dependent on nothing. it'll start executing immediately.
var async1 = flow.wait(function(finish, cancel) {
	asyncFn(function(err, data) {
		if(err) cancel(err);
		else finish(data);
	});
});

// this is dependent on async1. it'll start it's ready function as soon as
// async1 finishes. if async1 or async2 cancels, it'll execute it's cancelled
// function.
var async2 = flow.wait(async1, function(finish, cancel) {
	dependentAsyncFn(function(err, data) {
		if(err) cancel(err);
		else finish(data);
	});
}).cancelled(function(err) {
	console.log("this one didn't make it.");
});

// this isn't dependent on anything, so it'll also start executing it's ready
// function immediately. the function inside might not be asynchronous -- if it's
// synchronous, it'll finish (or cancel, if there's an error) immediately, and run
// it's finished() callback if successful.
var async3 = flow.wait(function(finish, cancel) {
	iDontEvenKnowIfThisIsAsynchronousButItKindaLooksLikeIt(function(err, data) {
		if(err) cancel(err);
		else finish(data);
	});
}).finished(function() {
	console.log("a glorious victory.");
});
```

SHOW ME MORE
============
More coming. For now, check out the tests.
